@@ -1,44 +1,28 @@
 #!/usr/bin/env python
-from __future__ import unicode_literals
-from itertools import islice
+import itertools
 from collections import namedtuple
 
 from django_countries.conf import settings
-from django.utils import six
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.translation import override
 
 from .base import CountriesBase
 
 try:
-    import pyuca
+    import pyuca  # noqa
 except ImportError:
     pyuca = None
-
-# Use UCA sorting if it's available.
-if pyuca:
-    collator = pyuca.Collator()
-
-    def sort_key(item):
-        return collator.sort_key(item[1])
-else:
+    # Fallback if the UCA sorting is not available.
     import unicodedata
-    # Cheap and dirty method to sort against ASCII characters only.
-
-    def sort_key(item):
-        return (
-            unicodedata.normalize('NFKD', item[1])
-            .encode('ascii', 'ignore').decode('ascii'))
 
 
-class CountryTuple(namedtuple('CountryTupleBase', ['code', 'name'])):
-
+class CountryTuple(namedtuple("CountryTupleBase", ["code", "name"])):
     def __repr__(self):
         """
         Display the repr as a standard tuple for better backwards
         compatibility with outputting this in a template.
         """
-        return '({this.code!r}, {this.name!r})'.format(this=self)
+        return "({this.code!r}, {this.name!r})".format(this=self)
 
 
 class Countries(CountriesBase):
@@ -57,7 +41,7 @@ class Countries(CountriesBase):
         value = getattr(self, option, None)
         if value is not None:
             return value
-        return getattr(settings, 'COUNTRIES_{0}'.format(option.upper()))
+        return getattr(settings, "COUNTRIES_{0}".format(option.upper()))
 
     @property
     def countries(self):
@@ -67,13 +51,13 @@ class Countries(CountriesBase):
 
         The result is cached so future lookups are less work intensive.
         """
-        if not hasattr(self, '_countries'):
-            only = self.get_option('only')
+        if not hasattr(self, "_countries"):
+            only = self.get_option("only")
             if only:
                 only_choices = True
                 if not isinstance(only, dict):
                     for item in only:
-                        if isinstance(item, six.string_types):
+                        if isinstance(item, str):
                             only_choices = False
                             break
             if only and only_choices:
@@ -82,26 +66,29 @@ class Countries(CountriesBase):
                 # Local import so that countries aren't loaded into memory
                 # until first used.
                 from django_countries.data import COUNTRIES
+
                 self._countries = dict(COUNTRIES)
-                if self.get_option('common_names'):
+                if self.get_option("common_names"):
                     self._countries.update(self.COMMON_NAMES)
-                override = self.get_option('override')
+                override = self.get_option("override")
                 if override:
                     self._countries.update(override)
                     self._countries = dict(
-                        (code, name) for code, name in self._countries.items()
-                        if name is not None)
+                        (code, name)
+                        for code, name in self._countries.items()
+                        if name is not None
+                    )
             if only and not only_choices:
                 countries = {}
                 for item in only:
-                    if isinstance(item, six.string_types):
+                    if isinstance(item, str):
                         countries[item] = self._countries[item]
                     else:
                         key, value = item
                         countries[key] = value
                 self._countries = countries
             self.countries_first = []
-            first = self.get_option('first') or []
+            first = self.get_option("first") or []
             for code in first:
                 code = self.alpha2(code)
                 if code in self._countries:
@@ -110,10 +97,25 @@ class Countries(CountriesBase):
 
     @property
     def alt_codes(self):
-        if not hasattr(self, '_alt_codes'):
+        if not hasattr(self, "_alt_codes"):
             # Again, local import so data is not loaded unless it's needed.
             from django_countries.data import ALT_CODES
+
             self._alt_codes = ALT_CODES
+            altered = False
+            for code, country in self.countries.items():
+                if isinstance(country, dict) and (
+                    "alpha3" in country or "numeric" in country
+                ):
+                    if not altered:
+                        self._alt_codes = self._alt_codes.copy()
+                        altered = True
+                    alt_codes = list(self._alt_codes.get(code, (None, None)))
+                    if "alpha3" in country:
+                        alt_codes[0] = country["alpha3"]
+                    if "numeric" in country:
+                        alt_codes[1] = country["numeric"]
+                    self._alt_codes[code] = tuple(alt_codes)
         return self._alt_codes
 
     @countries.deleter
@@ -123,32 +125,57 @@ class Countries(CountriesBase):
         internal options change. But surely no one is crazy enough to do that,
         right?
         """
-        if hasattr(self, '_countries'):
+        if hasattr(self, "_countries"):
             del self._countries
+        if hasattr(self, "_alt_codes"):
+            del self._alt_codes
 
-    def translate_pair(self, code):
+    def translate_code(self, code, ignore_first=None):
+        """
+        Return translated countries for a country code.
+        """
+        country = self.countries[code]
+        if isinstance(country, dict):
+            if "names" in country:
+                names = country["names"]
+            else:
+                names = [country["name"]]
+        else:
+            names = [country]
+        if ignore_first and code in ignore_first:
+            names = names[1:]
+        for name in names:
+            yield self.translate_pair(code, name)
+
+    def translate_pair(self, code, name=None):
         """
         Force a country to the current activated translation.
 
         :returns: ``CountryTuple(code, translated_country_name)`` namedtuple
         """
-        name = self.countries[code]
+        if name is None:
+            name = self.countries[code]
+            if isinstance(name, dict):
+                if "names" in name:
+                    name = name["names"][0]
+                else:
+                    name = name["name"]
         if code in self.OLD_NAMES:
             # Check if there's an older translation available if there's no
             # translation for the newest name.
             with override(None):
-                source_name = force_text(name)
-            name = force_text(name)
+                source_name = force_str(name)
+            name = force_str(name)
             if name == source_name:
                 for old_name in self.OLD_NAMES[code]:
                     with override(None):
-                        source_old_name = force_text(old_name)
-                    old_name = force_text(old_name)
+                        source_old_name = force_str(old_name)
+                    old_name = force_str(old_name)
                     if old_name != source_old_name:
                         name = old_name
                         break
         else:
-            name = force_text(name)
+            name = force_str(name)
         return CountryTuple(code, name)
 
     def __iter__(self):
@@ -172,27 +199,42 @@ class Countries(CountriesBase):
         countries = self.countries
 
         # Yield countries that should be displayed first.
-        countries_first = (
-            self.translate_pair(code)
-            for code in self.countries_first
-        )
+        countries_first = (self.translate_pair(code) for code in self.countries_first)
 
-        if self.get_option('first_sort'):
+        # Define the sorting method.
+        if pyuca:
+            collator = pyuca.Collator()
+
+            # Use UCA sorting if it's available.
+            def sort_key(item):
+                return collator.sort_key(item[1])
+        else:
+            # Cheap and dirty method to sort against ASCII characters only.
+            def sort_key(item):
+                return (
+                    unicodedata.normalize("NFKD", item[1])
+                    .encode("ascii", "ignore")
+                    .decode("ascii")
+                )
+
+        if self.get_option("first_sort"):
             countries_first = sorted(countries_first, key=sort_key)
 
         for item in countries_first:
             yield item
 
         if self.countries_first:
-            first_break = self.get_option('first_break')
+            first_break = self.get_option("first_break")
             if first_break:
-                yield ('', force_text(first_break))
+                yield ("", force_str(first_break))
 
         # Force translation before sorting.
-        first_repeat = self.get_option('first_repeat')
-        countries = (
-            self.translate_pair(code) for code in countries
-            if first_repeat or code not in self.countries_first)
+        ignore_first = None if self.get_option("first_repeat") else self.countries_first
+        countries = tuple(
+            itertools.chain.from_iterable(
+                self.translate_code(code, ignore_first) for code in countries
+            )
+        )
 
         # Return sorted country list.
         for item in sorted(countries, key=sort_key):
@@ -205,7 +247,7 @@ class Countries(CountriesBase):
 
         If no match is found, returns an empty string.
         """
-        code = force_text(code).upper()
+        code = force_str(code).upper()
         if code.isdigit():
             lookup_code = int(code)
 
@@ -228,7 +270,7 @@ class Countries(CountriesBase):
                     break
         if code in self.countries:
             return code
-        return ''
+        return ""
 
     def name(self, code):
         """
@@ -238,10 +280,10 @@ class Countries(CountriesBase):
         """
         code = self.alpha2(code)
         if code not in self.countries:
-            return ''
+            return ""
         return self.translate_pair(code)[1]
 
-    def by_name(self, country, language='en'):
+    def by_name(self, country, language="en"):
         """
         Fetch a country's ISO3166-1 two letter country code from its name.
 
@@ -262,7 +304,7 @@ class Countries(CountriesBase):
                     for old_name in self.OLD_NAMES[code]:
                         if old_name.lower() == country.lower():
                             return code
-        return ''
+        return ""
 
     def alpha3(self, code):
         """
@@ -275,7 +317,7 @@ class Countries(CountriesBase):
         try:
             return self.alt_codes[code][0]
         except KeyError:
-            return ''
+            return ""
 
     def numeric(self, code, padded=False):
         """
@@ -293,7 +335,7 @@ class Countries(CountriesBase):
         except KeyError:
             return None
         if padded:
-            return '%03d' % num
+            return "%03d" % num
         return num
 
     def __len__(self):
@@ -304,15 +346,13 @@ class Countries(CountriesBase):
         count = len(self.countries)
         # Add first countries, and the break if necessary.
         count += len(self.countries_first)
-        if self.countries_first and self.get_option('first_break'):
+        if self.countries_first and self.get_option("first_break"):
             count += 1
         return count
 
     def __bool__(self):
         return bool(self.countries)
 
-    __nonzero__ = __bool__
-
     def __contains__(self, code):
         """
         Check to see if the countries contains the given code.
@@ -325,10 +365,11 @@ class Countries(CountriesBase):
         choices by index.
         """
         try:
-            return next(islice(self.__iter__(), index, index+1))
+            return next(itertools.islice(self.__iter__(), index, index + 1))
         except TypeError:
-            return list(islice(self.__iter__(), index.start, index.stop,
-                               index.step))
+            return list(
+                itertools.islice(self.__iter__(), index.start, index.stop, index.step)
+            )
 
 
 countries = Countries()
