@@ -1,12 +1,12 @@
 try:
-    from django.utils.translation import ugettext_lazy as _
+    from django.utils.translation import gettext_lazy as _
 except ImportError:  # pragma: no cover
     # Allows this module to be executed without Django installed.
     def _(x):
         return x
 
 
-class CountriesBase(object):
+class CountriesBase:
     COMMON_NAMES = {
         "BN": _("Brunei"),
         "BO": _("Bolivia"),
@@ -16,7 +16,6 @@ class CountriesBase(object):
         "KR": _("South Korea"),
         "LA": _("Laos"),
         "MD": _("Moldova"),
-        "MK": _("Macedonia"),
         "RU": _("Russia"),
         "SY": _("Syria"),
         "TW": _("Taiwan"),
@@ -27,6 +26,9 @@ class CountriesBase(object):
 
     OLD_NAMES = {
         "CZ": [_("Czech Republic")],
+        "MK": [_("Macedonia"), _("Macedonia (the former Yugoslav Republic of)")],
+        "SZ": [_("Swaziland")],
+        "TZ": [_("Tanzania, the United Republic of")],
     }
 
     def __getstate__(self):
