@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 This is a self-generating script that contains all of the iso3166-1 data.
 
@@ -8,26 +7,26 @@ how to do that:
 
 1. Visit https://www.iso.org/obp
 2. Click the "Country Codes" radio option and click the search button
-3. Filter by "Officially assigned codes"
-4. Change the results per page to 300
-5. Copy the html table and paste into Libreoffice Calc / Excel
-6. Delete the French name column
+3. Change the results per page to 300
+4. Copy the html table and paste into Libreoffice Calc / Excel
+5. Delete the French short name column
+6. Delete the heading row.
 7. Save as a CSV file in django_countries/iso3166-1.csv
 8. Run this script from the command line
 """
-from __future__ import unicode_literals
 import glob
 import os
 
 from django_countries.base import CountriesBase
 
 try:
-    from django.utils.translation import ugettext_lazy as _
+    from django.utils.translation import gettext_lazy as _
 except ImportError:  # pragma: no cover
     # Allows this module to be executed without Django installed.
     def _(x):
         return x
 
+
 # Nicely titled (and translatable) country names.
 COUNTRIES = {
     "AF": _("Afghanistan"),
@@ -100,6 +99,7 @@ COUNTRIES = {
     "GQ": _("Equatorial Guinea"),
     "ER": _("Eritrea"),
     "EE": _("Estonia"),
+    "SZ": _("Eswatini"),
     "ET": _("Ethiopia"),
     "FK": _("Falkland Islands  [Malvinas]"),
     "FO": _("Faroe Islands"),
@@ -161,7 +161,6 @@ COUNTRIES = {
     "LT": _("Lithuania"),
     "LU": _("Luxembourg"),
     "MO": _("Macao"),
-    "MK": _("Macedonia (the former Yugoslav Republic of)"),
     "MG": _("Madagascar"),
     "MW": _("Malawi"),
     "MY": _("Malaysia"),
@@ -194,6 +193,7 @@ COUNTRIES = {
     "NG": _("Nigeria"),
     "NU": _("Niue"),
     "NF": _("Norfolk Island"),
+    "MK": _("North Macedonia"),
     "MP": _("Northern Mariana Islands"),
     "NO": _("Norway"),
     "OM": _("Oman"),
@@ -243,13 +243,12 @@ COUNTRIES = {
     "SD": _("Sudan"),
     "SR": _("Suriname"),
     "SJ": _("Svalbard and Jan Mayen"),
-    "SZ": _("Swaziland"),
     "SE": _("Sweden"),
     "CH": _("Switzerland"),
     "SY": _("Syrian Arab Republic"),
     "TW": _("Taiwan (Province of China)"),
     "TJ": _("Tajikistan"),
-    "TZ": _("Tanzania, United Republic of"),
+    "TZ": _("Tanzania, the United Republic of"),
     "TH": _("Thailand"),
     "TL": _("Timor-Leste"),
     "TG": _("Togo"),
@@ -352,6 +351,7 @@ ALT_CODES = {
     "GQ": ("GNQ", 226),
     "ER": ("ERI", 232),
     "EE": ("EST", 233),
+    "SZ": ("SWZ", 748),
     "ET": ("ETH", 231),
     "FK": ("FLK", 238),
     "FO": ("FRO", 234),
@@ -413,7 +413,6 @@ ALT_CODES = {
     "LT": ("LTU", 440),
     "LU": ("LUX", 442),
     "MO": ("MAC", 446),
-    "MK": ("MKD", 807),
     "MG": ("MDG", 450),
     "MW": ("MWI", 454),
     "MY": ("MYS", 458),
@@ -446,6 +445,7 @@ ALT_CODES = {
     "NG": ("NGA", 566),
     "NU": ("NIU", 570),
     "NF": ("NFK", 574),
+    "MK": ("MKD", 807),
     "MP": ("MNP", 580),
     "NO": ("NOR", 578),
     "OM": ("OMN", 512),
@@ -495,7 +495,6 @@ ALT_CODES = {
     "SD": ("SDN", 729),
     "SR": ("SUR", 740),
     "SJ": ("SJM", 744),
-    "SZ": ("SWZ", 748),
     "SE": ("SWE", 752),
     "CH": ("CHE", 756),
     "SY": ("SYR", 760),
@@ -534,8 +533,7 @@ ALT_CODES = {
 }
 
 
-def self_generate(
-        output_filename, filename='iso3166-1.csv'):  # pragma: no cover
+def self_generate(output_filename, filename="iso3166-1.csv"):  # pragma: no cover
     """
     The following code can be used for self-generation of this file.
 
@@ -544,45 +542,43 @@ def self_generate(
     """
     import csv
     import re
+
     countries = []
     alt_codes = []
-    with open(filename, 'rb') as csv_file:
+    with open(filename, "r") as csv_file:
         for row in csv.reader(csv_file):
-            name = row[0].decode('utf-8').rstrip('*')
-            name = re.sub(r'\(the\)', '', name)
+            name = row[0].rstrip("*")
+            name = re.sub(r"\(the\)", "", name)
             if name:
-                countries.append((name, row[1].decode('utf-8')))
-                alt_codes.append((
-                    row[1].decode('utf-8'),
-                    row[2].decode('utf-8'),
-                    int(row[3]),
-                ))
-    with open(__file__, 'r') as source_file:
+                countries.append((name, row[1]))
+                alt_codes.append((row[1], row[2], int(row[3])))
+    with open(__file__, "r") as source_file:
         contents = source_file.read()
     # Write countries.
-    bits = re.match(
-        '(.*\nCOUNTRIES = \{\n)(.*?)(\n\}.*)', contents, re.DOTALL).groups()
+    bits = re.match("(.*\nCOUNTRIES = \{\n)(.*?)(\n\}.*)", contents, re.DOTALL).groups()
     country_list = []
     for name, code in countries:
-        name = name.replace('"', r'\"').strip()
-        country_list.append(
-            '    "{code}": _("{name}"),'.format(name=name, code=code))
+        name = name.replace('"', r"\"").strip()
+        country_list.append('    "{code}": _("{name}"),'.format(name=name, code=code))
     content = bits[0]
-    content += '\n'.join(country_list).encode('utf-8')
+    content += "\n".join(country_list)
     # Write alt codes.
     alt_bits = re.match(
-        '(.*\nALT_CODES = \{\n)(.*)(\n\}.*)', bits[2], re.DOTALL).groups()
+        "(.*\nALT_CODES = \{\n)(.*)(\n\}.*)", bits[2], re.DOTALL
+    ).groups()
     alt_list = []
     for code, code3, codenum in alt_codes:
-        name = name.replace('"', r'\"').strip()
+        name = name.replace('"', r"\"").strip()
         alt_list.append(
             '    "{code}": ("{code3}", {codenum}),'.format(
-                code=code, code3=code3, codenum=codenum))
+                code=code, code3=code3, codenum=codenum
+            )
+        )
     content += alt_bits[0]
-    content += '\n'.join(alt_list).encode('utf-8')
+    content += "\n".join(alt_list)
     content += alt_bits[2]
     # Generate file.
-    with open(output_filename, 'wb') as output_file:
+    with open(output_filename, "w") as output_file:
         output_file.write(content)
     return countries
 
@@ -590,7 +586,7 @@ def self_generate(
 def check_flags(verbosity=1):
     files = {}
     this_dir = os.path.dirname(__file__)
-    for path in glob.glob(os.path.join(this_dir, 'static', 'flags', '*.gif')):
+    for path in glob.glob(os.path.join(this_dir, "static", "flags", "*.gif")):
         files[os.path.basename(os.path.splitext(path)[0]).upper()] = path
 
     flags_missing = set(COUNTRIES) - set(files)
@@ -603,7 +599,7 @@ def check_flags(verbosity=1):
 
     code_missing = set(files) - set(COUNTRIES)
     # Special-case EU and __
-    for special_code in ('EU', '__'):
+    for special_code in ("EU", "__"):
         code_missing.discard(special_code)
     if code_missing:  # pragma: no cover
         print("")
@@ -616,16 +612,14 @@ def check_common_names():
     common_names_missing = set(CountriesBase.COMMON_NAMES) - set(COUNTRIES)
     if common_names_missing:  # pragma: no cover
         print("")
-        print(
-            "The following common names do not match an official country "
-            "code:")
+        print("The following common names do not match an official country code:")
         for code in sorted(common_names_missing):
             print("  {0}".format(code))
 
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == "__main__":  # pragma: no cover
     countries = self_generate(__file__)
-    print('Wrote {0} countries.'.format(len(countries)))
+    print("Wrote {0} countries.".format(len(countries)))
 
     print("")
     check_flags()
