@@ -2,4 +2,4 @@ from django_countries import Countries
 
 
 class FantasyCountries(Countries):
-    only = ['NZ', ('NV', 'Neverland')]
+    only = ["NZ", ("NV", "Neverland")]
